@@ -20,6 +20,13 @@ require 'tomlrb'
 require 'tty-platform'
 require 'zeitwerk'
 
+# External gems (optional)
+begin
+  require 'clonefile'
+rescue LoadError
+  # ignore
+end
+
 module Nanoc
   module Core
     # Similar to `nil` except that it can only be compared against using
@@ -32,7 +39,7 @@ module Nanoc
     #
     # @api private
     def self.version_information
-      "Nanoc #{Nanoc::VERSION} © 2007–2019 Denis Defreyne.\n" \
+      "Nanoc #{Nanoc::VERSION} © 2007–2021 Denis Defreyne.\n" \
       "Running #{RUBY_ENGINE} #{RUBY_VERSION} (#{RUBY_RELEASE_DATE}) on #{RUBY_PLATFORM} with RubyGems #{Gem::VERSION}.\n"
     end
 
