@@ -2,21 +2,21 @@
 
 module Nanoc::RuleDSL
   class RoutingRule < Rule
-    include Nanoc::Int::ContractsSupport
+    include Nanoc::Core::ContractsSupport
 
     contract C::None => C::Maybe[Symbol]
     attr_reader :snapshot_name
 
-    contract Nanoc::Int::Pattern, Symbol, Proc, C::KeywordArgs[snapshot_name: C::Optional[Symbol]] => C::Any
+    contract Nanoc::Core::Pattern, Symbol, Proc, C::KeywordArgs[snapshot_name: C::Optional[Symbol]] => C::Any
     def initialize(pattern, rep_name, block, snapshot_name: nil)
       super(pattern, rep_name, block)
 
       @snapshot_name = snapshot_name
     end
 
-    contract Nanoc::Int::ItemRep, C::KeywordArgs[
-      site: Nanoc::Int::Site,
-      view_context: Nanoc::ViewContextForPreCompilation,
+    contract Nanoc::Core::ItemRep, C::KeywordArgs[
+      site: Nanoc::Core::Site,
+      view_context: Nanoc::Core::ViewContextForPreCompilation,
     ] => C::Any
     def apply_to(rep, site:, view_context:)
       context = Nanoc::RuleDSL::RoutingRuleContext.new(
