@@ -5,9 +5,6 @@ $VERBOSE = false
 require 'simplecov'
 SimpleCov.start
 
-require 'codecov'
-SimpleCov.formatter = SimpleCov::Formatter::Codecov
-
 require 'minitest/autorun'
 require 'mocha/minitest'
 require 'vcr'
